/************************************************************************/
/* Copyright:	(c) Andrew Richards, 2000				*/
/************************************************************************/
/* License:	GNU General Public License version 2. This is contained	*/
/*		in the file gpl.txt supplied along with this program.	*/
/************************************************************************/
/* Authors:	Andrew Richards andrew@tic.ch (Advert: I offer qmail	*/
/*		  consultancy services - ich spreche auch Deutsch)	*/
/************************************************************************/
/* 09May2001	ACR	Removed function prototypes for non-existent	*/
/*			functions!					*/
/************************************************************************/

void tidystringtail(char *str);		/* Removes trailing white space */
void convertpopstring(char *popstring);	/* % becomes @			*/
char *stripusername(char *s);		/* "@domain" from "user@domain"	*/
void stringclean(char *popstring);	/* tidy+decap+xvert		*/
int str_checkchars(char *s,char *validchars);
